```{eval-rst} 
:og:description: Gloe is a general-purpose library designed to guide developers in expressing their code as a flow.

:og:image:alt: Gloe is a general-purpose library designed to guide developers in expressing their code as a flow.

.. meta::
  :description: Gloe is a general-purpose library designed to guide developers in expressing their code as a flow.
```

```{include} ../../README.md
```


```{toctree}
:caption: 'Contents'
:maxdepth: 3
:hidden:

Introduction <self>
getting-started/index
faq
philosophy
limitations

```


```{toctree}
:caption: 'Learn'
:maxdepth: 3
:hidden:


examples/index
patterns/index
advanced/index
```

```{toctree}
:caption: 'Development'
:maxdepth: 3
:hidden:

api-reference/index
```